// src/index.ts
import _set from "just-safe-set";
var DEFAULT_OPTIONS = {
  prefix: "VITECONFIG_",
  separator: "_"
};
function parseValue(val) {
  if (val === "undefined" || val === void 0) {
    return void 0;
  }
  try {
    return JSON.parse(val);
  } catch (e) {
    return `${val}`;
  }
}
function env2config(options) {
  const { prefix, separator } = options;
  return Object.keys(process.env).filter((key) => key.startsWith(prefix)).map((key) => {
    const path = key.substring(prefix.length).split(separator).join(".");
    const val = parseValue(process.env[key]);
    return { path, val };
  }).reduce((acc, { path, val }) => {
    _set(acc, path, val);
    return acc;
  }, {});
}
function envConfig(inlineOptions) {
  const options = {
    ...DEFAULT_OPTIONS,
    ...inlineOptions
  };
  return {
    name: "vite-plugin-env-config",
    config() {
      const config = env2config(options);
      return config;
    }
  };
}
export {
  envConfig
};
//# sourceMappingURL=index.js.map